@@ -1,17 +1,15 @@
 package Test::Media;
 
-use Test::Most;
+use Test::Exception;
 use Test::Roo::Role;
 
 test 'media tests' => sub {
 
-    diag Test::Media;
-
     my $self = shift;
 
     my $ret;
 
-    my $schema = $self->schema;
+    my $schema = $self->ic6s_schema;
 
     my %product_data = (
         sku               => 'G000X',
